/**
 * @file
 * VuoList_VuoNoise C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoNoise_H
#define VuoList_VuoNoise_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoNoise VuoList_VuoNoise
 * A list of @ref VuoNoise elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoNoise
 * A list of @ref VuoNoise elements.
 */
#ifndef VuoList_VuoNoise_TYPE_DEFINED
typedef void * VuoList_VuoNoise;
#endif

/**
 * Creates a new list of @ref VuoNoise elements.
 */
VuoList_VuoNoise VuoListCreate_VuoNoise(void);

/**
 * Returns the @ref VuoNoise at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoNoise VuoListGetValueAtIndex_VuoNoise(const VuoList_VuoNoise list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoNoise(VuoList_VuoNoise list, const VuoNoise value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoNoise(VuoList_VuoNoise list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoNoise(VuoList_VuoNoise list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoNoise(const VuoList_VuoNoise list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoNoise VuoList_VuoNoise_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoNoise_jsonFromValue(const VuoList_VuoNoise value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoNoise_summaryFromValue(const VuoList_VuoNoise value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoNoise VuoList_VuoNoise_valueFromString(const char *str);
char * VuoList_VuoNoise_stringFromValue(const VuoList_VuoNoise value);
/// @}

/**
 * @}
 */

#endif
